# epystemology

[![PyPI - Version](https://img.shields.io/pypi/v/epystemology.svg)](https://pypi.org/project/epystemology)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/epystemology.svg)](https://pypi.org/project/epystemology)

Create a declarative source of truth for input to your application.

> **Epistemology:** the theory of knowledge, especially with regard to its
> methods, validity, and scope, and the distinction between justified belief
> and opinion.

---

## **Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install epystemology
```

## License

`epystemology` is distributed under the terms of the
[MIT](https://spdx.org/licenses/MIT.html) license.

## Usage
